package keskustelubotti;

import java.util.*;

/**
 * Jono johon voi laittaa uusia lauseita ja hakea niit laittojrjestyksess.
 *
 * Lausejonoon laitetaan botille menevt, ksittely odottavat lauseet, sek botilta tulevat
 * valmiit, sanomista odottavat lauseet.
 *
 * Lisksi jonoon laitetaan "kellonaika" lauseille, eli botille menevien lauseiden sanomisaika,
 * vaikkei sill juuri mitn teekn, ja botilta tulevien lauseiden laskettu sanomisaika.
 *
 * Jonoon talletetaan mys, onko listtv lause vastauslause vai oma-aloitteinen lause.
 * (Mik ei taaskaan oikein pde botille menevien lauseiden jonossa, vaan en
 * jaksanut alkaa stmn erillisi jonoja botille/botilta -lauseille.)
 *
 * Toteutettu javan LinkedListin; ensimmisen ja viimeisen lisys/poisto vakioaikainen.
 *
 * @author Samuli Kaipiainen
 * @version 0.1
 */
 public class Lausejono
{
	private final LinkedList jono;

	/**
	 * jonoon laitettavat lauseet, sisltvt itse lauseen (String) ett ajan (long)
	 */
	private class Lause
	{
		private String lause;
		private long aika;
		private boolean vastaus;

		private Lause(String lause, long aika, boolean vastaus)
		{
			this.lause = lause;
			this.aika = aika;
			this.vastaus = vastaus;
		}
	}

	/**
	 * Luo tyhjn lausejonon
	 */
	public Lausejono()
	{
		jono = new LinkedList();
	}

	/**
	 * Lis lausejonoon uuden lauseen
	 *
	 * @param lause Listtv lause
	 * @param aika Lauseen aika
	 * @param vastaus Onko listtv lause vastauslause (eik oma-aloitteinen)
	 */
	public void lisLause(String lause, long aika, boolean vastaus)
	{
		jono.addLast(new Lause(lause, aika, vastaus));
	}

	/**
	 * Palauttaa seuraavana jonossa olevan lauseen JA poistaa sen jonosta
	 *
	 * @return Seuraavana jonossa oleva lause; null jos tyhj
	 */
	public String seuraavaLause()
	{
		if (onLauseita()) return ((Lause) jono.removeFirst()).lause;
		else return null;
	}

	/**
	 * Palauttaa seuraavana jonossa olevan lauseen kellonajan; ei poista lausetta jonosta
	 *
	 * @return Seuraavana jonossa olevan lauseen aika, -1 jos jono on tyhj
	 */
	public long seuraavanAika()
	{
		if (onLauseita()) return ((Lause) jono.getFirst()).aika;
		else return -1;
	}

	/**
	 * Palauttaa viimeisen jonossa olevan lauseen kellonajan; ei poista lausetta jonosta
	 *
	 * @return Viimeisen jonossa olevan lauseen aika, System.currentTimeMillis() jos jono on tyhj
	 */
	public long viimeisenAika()
	{
		if (onLauseita()) return ((Lause) jono.getLast()).aika;
		else return System.currentTimeMillis();
	}

	/**
	 * Kertoo, onko jonossa seuraavana oleva lause vastauslause
	 *
	 * @return true jos vastaus, false jos oma-aloitteinen tai jono on tyhj
	 */
	public boolean seuraavaOnVastaus()
	{
		if (onLauseita()) return ((Lause) jono.getFirst()).vastaus;
		else return false;
	}

	/**
	 * Kertoo, onko jonossa seuraavana oleva lause oma-aloitteinen
	 *
	 * @return true jos oma-aloitteinen, false jos vastaus tai jono on tyhj
	 */
	public boolean seuraavaOnOma()
	{
		if (onLauseita()) return !((Lause) jono.getFirst()).vastaus;
		else return false;
	}

	/**
	 * @return Onko lausejonossa lauseita
	 */
	public boolean onLauseita()
	{
		return !jono.isEmpty();
	}

	/**
	 * @return Onko lausejono tyhj
	 */
	public boolean onTyhj()
	{
		return jono.isEmpty();
	}
}
