package keskustelubotti;

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;

/**
 * Ohjeikkuna, avaa tekstilaatikkoon botin kyttohjeen.
 *
 * @author Samuli Kaipiainen
 * @version 0.1
 */

public class Ohjeikkuna extends JFrame
{
	// ohjeikkunan tavarat

	// tekstilaatikko
	private final JTextArea tekstilaatikko = new JTextArea();

	// tekstilaatikko tulee vierityspaneelin sisn
	private final JScrollPane vierityspaneeli = new JScrollPane(tekstilaatikko);

	// poistumisnappula
	private final JButton nappula = new JButton("Okra, pois tyhm ohje");

	// paneeli nappulalle (nappula tulee paneelin sislle)
	private final JPanel alapaneeli = new JPanel(new FlowLayout(FlowLayout.CENTER));

	/**
	 * Rakennetaan ohjeikkuna, ei kuitenkaan nyt ikkunaa
	 *
	 * @param tiedosto Kyttohjetiedosto joka luetaan tekstilaatikkoon
	 */
	public Ohjeikkuna(String tiedosto)
	{
		// tekstilaatikon asetukset
		tekstilaatikko.setEditable(false);
		tekstilaatikko.setLineWrap(true);
		tekstilaatikko.setWrapStyleWord(true);
		tekstilaatikko.setFont(new Font("Courier New", Font.PLAIN, 12));
		tekstilaatikko.setBackground(new Color(0xeeeeff));
		vierityspaneeli.setPreferredSize(new Dimension(700, 500));
		vierityspaneeli.setVerticalScrollBarPolicy(JScrollPane.VERTICAL_SCROLLBAR_ALWAYS);

		// laitetaan nappula alapaneeliin
		alapaneeli.add(nappula);

		// listn tavarat ikkunaan
		this.getContentPane().add(vierityspaneeli, BorderLayout.CENTER);
		this.getContentPane().add(alapaneeli, BorderLayout.SOUTH);

		// nappulan tapahtumaksittelij
		nappula.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) { suljeOhjeIkkuna(); }
		});

		// tapahtumaksittelij ikkunan sulkemiselle
		this.addWindowListener(new WindowAdapter() {
			public void windowClosing(WindowEvent e) { suljeOhjeIkkuna(); }
		});

		// luetaan kyttohje tekstilaatikkoon
		tekstilaatikko.setText(lueTiedosto(tiedosto));

		this.setTitle("Keskustelubotti / kyttohje");
		this.pack();
	}

	/**
	 * Sulkee ohjeikkunan, paitsi ettei suljekaan vaan vain kevyesti piilottaa
	 */
	private void suljeOhjeIkkuna()
	{
		this.hide();
	}

	/**
	 * Lukee tiedoston (kyttohjeen)
	 *
	 * @param tiedosto Mit luetaan
	 * @return Tiedoston sislt
	 */
	private String lueTiedosto(String tiedosto)
	{
		StringBuffer teksti = new StringBuffer();
		Tiedostolukija t = new Tiedostolukija(tiedosto);

		if (!t.avattuOK()) return "IIK, kyttohjetiedostoa ei lydy: '" + tiedosto + "'\n";

		for (String s = t.seuraavaRivi(); s != null; s = t.seuraavaRivi())
			teksti.append(s + "\n");

		t.sulje();

		return teksti.toString();
	}
}
