package keskustelubotti;

import java.io.*;

/**
 * Lukee tiedostoa rivi kerrallaan.
 *
 * @author Samuli Kaipiainen
 * @version 0.1
 */

public class Tiedostolukija
{
	private final String tiedosto;
	// ei voi olla final, koska java itkee ett se joko saa arvon tai ei saa konstruktorin try-lohkossa
	private BufferedReader in;
	private boolean avattuOK;

	/**
	 * Luo uuden tiedostolukijan, jos tiedoston avaus onnitui, avattuOK palauttaa true
	 *
	 * @param tiedosto Mit luetaan
	 */
	public Tiedostolukija(String tiedosto)
	{
		this.tiedosto = tiedosto;
		avattuOK = true;

		try {
			in = new BufferedReader(new FileReader(tiedosto));
		} catch (FileNotFoundException e) {
			Main.error("virhe avattaessa '" + tiedosto + "': " + e.getMessage());
			avattuOK = false;
		}
	}

	/**
	 * @return true jos tiedoston avaus konstruktorissa onnistui; muuten false
	 */
	public boolean avattuOK()
	{
		return avattuOK;
	}

	/**
	 * Sulkee avatun tiedoston, jonka jlkeen tll ilmentymll ei tee en mitn
	 *
	 * @return true jos sulkeminen onnistui; muuten false
	 */
	public boolean sulje()
	{
		if (!avattuOK) return false;

		try {
			in.close();
		} catch (IOException e) {
			Main.error("virhe suljettaessa '" + tiedosto + "': " + e.getMessage());
			return false;
		}

		return true;
	}

	/**
	 * @return Seuraava rivi tiedostosta; null jos tiedosto loppu tai virhe jossain vaiheessa
	 */
	public String seuraavaRivi()
	{
		if (!avattuOK) return null;

		String s;

		try {
			s = in.readLine();
		} catch (IOException e) {
			Main.error("virhe luettaessa <-'" + tiedosto + "': " + e.getMessage());
			return null;
		}

		return s;
	}
}
